<?php

// Exit if accessed directly
if ( !defined('ABSPATH') ) exit;

/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom Widgets, custom hooks, and Theme settings.
 * 
 * @package 	mantel
 * @author		Tokokoo
 * @license		license.txt
 * @since 		1.0
 *
 */
 
 /* Load the core theme framework. */
require_once( trailingslashit( get_template_directory() ) . 'library/hybrid.php' );
new Hybrid();

/* Do theme setup on the 'after_setup_theme' hook. */
add_action( 'after_setup_theme', 'mantel_theme_setup' );

/**
 * Theme setup function. This function adds support for theme features and defines the default theme
 * actions and filters.
 *
 * @since 1.0
 */
function mantel_theme_setup() {

	/* Get action/filter hook prefix. */
	$prefix = hybrid_get_prefix();

	// Define the version as a constant
	define( 'MANTEL_VERSION', 1.1 );
	define( 'MANTEL_ADMIN', trailingslashit( THEME_DIR ) . 'admin' );
	define( 'MANTEL_INCLUDES', trailingslashit( THEME_DIR ) . 'includes' );
	define( 'MANTEL_JS', trailingslashit( THEME_URI ) . 'js' );

	/* Add theme settings */
	if ( is_admin() )
	    require_once( trailingslashit( MANTEL_ADMIN ) . 'functions-admin.php' );
   		require_once( trailingslashit( MANTEL_ADMIN ) . 'premium-upgrade.php' );

	/* Load the custom theme additional functions. */
    require_once( trailingslashit( MANTEL_INCLUDES ) . 'theme-functions.php' );

	/* Add theme support for core framework features. */
	add_theme_support( 'hybrid-core-menus', array( 'primary', 'subsidiary' ) );
	add_theme_support( 'hybrid-core-sidebars', array( 'primary', 'subsidiary' ) );
	add_theme_support( 'hybrid-core-widgets' );
	add_theme_support( 'hybrid-core-shortcodes' );
	add_theme_support( 'hybrid-core-theme-settings', array( 'footer', 'about' ) );
	add_theme_support( 'hybrid-core-styles', array( 'gallery', 'parent', 'style' ) );

	/* Add theme support for framework extensions. */
	add_theme_support( 'theme-layouts', array( '1c', '1c-full', '2c-l', '2c-r' ), array( 'default' => '2c-l' ) );
	add_theme_support( 'loop-pagination' );
	add_theme_support( 'get-the-image' );
	add_theme_support( 'breadcrumb-trail' );
	add_theme_support( 'cleaner-gallery' );
	add_theme_support( 'cleaner-caption' );

	/* Add theme support for WordPress features. */
	add_editor_style();
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'post-formats', array( 'aside', 'image', 'gallery', 'quote', 'link' ) );

	/* Set content width. */
	hybrid_set_content_width( 700 );

	/* Filter the sidebar widgets. */
	add_filter( 'sidebars_widgets', 'mantel_disable_sidebars' );
	add_action( 'template_redirect', 'mantel_one_column' );

	/* Embed width/height defaults. */
	add_filter( 'embed_defaults', 'mantel_embed_defaults' );

	/* Add classes to the comments pagination. */
	add_filter( 'previous_comments_link_attributes', 'mantel_previous_comments_link_attributes' );
	add_filter( 'next_comments_link_attributes', 'mantel_next_comments_link_attributes' );

	/* Add custom image sizes. */
	add_action( 'init', 'mantel_add_image_sizes' );

	/* Load the theme stylesheet. */
	add_action( 'wp_enqueue_scripts', 'mantel_additional_styles' );

	/* Load the theme scripts. */
	add_action( 'wp_enqueue_scripts', 'mantel_scripts' );

	/* Load the comment reply js. */
	add_action( 'comment_form_before', 'mantel_enqueue_comment_reply_script' );

	/* Sets the post excerpt length to 50 words. */
	add_filter( 'excerpt_length', 'mantel_excerpt_length' );

	/* Replaces "[...]" (appended to automatically generated excerpts). */
	add_filter( 'excerpt_more', 'mantel_auto_excerpt_more' );

	/* Adds a pretty "Continue Reading" link to custom post excerpts. */
	add_filter( 'get_the_excerpt', 'mantel_custom_excerpt_more' );

	/* Removes default styles set by WordPress recent comments widget. */
	add_action( 'widgets_init', 'mantel_remove_recent_comments_style' );

	/* Register additional widgets. */
	add_action( 'widgets_init', 'mantel_register_widgets' );

	/* Remove gallery inline style. */
	add_filter( 'use_default_gallery_style', '__return_false' );

	/* Stop more link from jumping to middle of page. */
	add_filter( 'the_content_more_link', 'mantel_remove_more_jump_link' );

	/* Remove theme-layouts meta box from custom post type */
	add_action( 'init', 'mantel_remove_theme_layout_metabox', 11 );

	/* Load the breadcrumb-trail. */
	add_action( 'mantel_main_before', 'mantel_breadcrumbs', 1 );

	/* Filter size of the gravatar on comments. */
	add_filter( "{$prefix}_list_comments_args", 'mantel_comments_args' );

	/* Flush rewrite rules for custom post types. */
	add_action( 'load-themes.php', 'mantel_flush_rewrite_rules' );

	/* Default footer settings */
	add_filter( "{$prefix}_default_theme_settings", 'mantel_default_footer_settings' );

	/* Add no widgets layout. */
	add_filter( 'theme_layouts_strings', 'mantel_register_theme_layout' );

} // mantel_theme_setup()

/**
 * Function for deciding which pages should have a one-column layout.
 *
 * @since 1.0
 */
function mantel_one_column() {

	if ( is_attachment() && 'layout-default' == theme_layouts_get_layout() )
		add_filter( 'get_theme_layout', 'mantel_theme_layout_one_column' );

}

/**
 * Filters 'get_theme_layout' by returning 'layout-1c'.
 *
 * @since 1.0
 */
function mantel_theme_layout_one_column( $layout ) {

	return 'layout-1c';

}

/**
 * Disables sidebars if viewing a one-column page.
 *
 * @since 1.0
 */
function mantel_disable_sidebars( $sidebars_widgets ) {

	if ( current_theme_supports( 'theme-layouts' ) && ! is_admin() ) {

		if ( is_page_template( 'page-templates/landing.php' ) || is_page_template( 'page-templates/fullwidth.php' ) ) {
			$sidebars_widgets['primary'] = false;
		}

		if ( 'layout-1c' == theme_layouts_get_layout() || 'layout-1c-full' == theme_layouts_get_layout() ) {
			$sidebars_widgets['primary'] = false;
		}
		
	}

	return $sidebars_widgets;

}

/**
 * Overwrites the default widths for embeds. This is especially useful for making sure videos properly
 * expand the full width on video pages. This function overwrites what the $content_width variable handles
 * with context-based widths.
 *
 * @since 1.0
 */
function mantel_embed_defaults( $args ) {

	$args['width'] = 700;

	if ( current_theme_supports( 'theme-layouts' ) ) {

		$layout = theme_layouts_get_layout();

		if ( 'layout-1c-full' == $layout )
			$args['width'] = 725;

	}

	return $args;
}

/**
 * Adds 'class="prev" to the previous comments link.
 *
 * @since 1.0
 */
function mantel_previous_comments_link_attributes( $attributes ) {
	return $attributes . ' class="prev"';
}

/**
 * Adds 'class="next" to the next comments link.
 *
 * @since 1.0
 */
function mantel_next_comments_link_attributes( $attributes ) {
	return $attributes . ' class="next"';
}

/**
 * Adds custom image sizes.
 *
 * @since 1.0
 */
function mantel_add_image_sizes() {

	add_image_size( 'Mantel_Format_Image', 700, 280, true );
	add_image_size( 'Mantel_Format_Gallery', 700, 300, true );
	add_image_size( 'Mantel_Widget', 45, 45, true );
	add_image_size( 'Mantel_Featured', 940, 440, true );

}

/**
 * Load the theme stylesheet.
 *
 * @since 1.0
 */
function mantel_additional_styles() {

	wp_enqueue_style( 'mantel-fonts', 'http://fonts.googleapis.com/css?family=Patua+One|Lato:400,700,900', '', MANTEL_VERSION, 'all' );

	wp_enqueue_style( 'mantel-plugins', trailingslashit ( THEME_URI ) . 'plugins.css', '', MANTEL_VERSION, 'all' );

	wp_enqueue_style( 'mantel-themes-style', trailingslashit ( THEME_URI ) . 'includes/themes/themes.css', '', MANTEL_VERSION, 'all' );

}

/**
 * Load the theme scripts.
 *
 * @since 1.0
 */
function mantel_scripts() {
	
	wp_enqueue_script( 'jquery' );
	
	wp_enqueue_script( 'mantel-modernizr', trailingslashit ( MANTEL_JS ) . 'vendor/modernizr-2.6.2.min.js', array( 'jquery' ), '2.6.2' );
	
	wp_enqueue_script( 'mantel-plugins', trailingslashit ( MANTEL_JS ) . 'plugins.js', array( 'jquery' ), MANTEL_VERSION, true );
	
	wp_enqueue_script( 'mantel-methods', trailingslashit ( MANTEL_JS ) . 'methods.js', array( 'jquery' ), MANTEL_VERSION, true );

	wp_enqueue_script( 'mantel-themes-script', trailingslashit ( THEME_URI ) . 'includes/themes/theme.js', array('jquery'), MANTEL_VERSION, true );
	
}

/**
 * Load the comment reply js.
 *
 * @since 1.0
 */
function mantel_enqueue_comment_reply_script() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}

/**
 * Sets the post excerpt length to 50 words.
 *
 * @since 1.0
 */
function mantel_excerpt_length( $length ) {
	return 50;
}

/**
 * Returns a "Continue Reading" link for excerpts
 *
 * @since 1.0
 */
function mantel_continue_reading_link() {
	return ' <a class="readmore" href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'mantel' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) 
 * with an ellipsis and mantel_continue_reading_link().
 *
 * @since 1.0
 */
function mantel_auto_excerpt_more( $more ) {
	return ' &hellip;' . mantel_continue_reading_link();
}

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * @since 1.0
 */
function mantel_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= mantel_continue_reading_link();
	}
	return $output;
}

/**
 * Removes default styles set by WordPress recent comments widget.
 *
 * @since 1.0
 */
function mantel_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}

/**
 * Count the number of widgets to enable dynamic classes
 *
 * @since 1.0
 */
function mantel_dynamic_sidebar_class( $sidebar_id ) {

	$sidebars = wp_get_sidebars_widgets();
	$get_count = count( $sidebars[$sidebar_id] );

	$class = '';

	switch ( $get_count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class )
		echo $class;

}

/**
 * Registers extra widgets.
 * 
 * @since 1.0
 */
function mantel_register_widgets() {

	require_once( trailingslashit ( MANTEL_INCLUDES ) . 'widgets/widget-social.php' );
	register_widget( 'mantel_social' );

	require_once( trailingslashit ( MANTEL_INCLUDES ) . 'widgets/widget-subscribe.php' );
	register_widget( 'mantel_subscribe' );

	require_once( trailingslashit ( MANTEL_INCLUDES ) . 'widgets/widget-blog-posts.php' );
	register_widget( 'mantel_blog_posts' );

}

/**
 * Stop more link from jumping to middle of page.
 *
 * @since 1.0
 */
function mantel_remove_more_jump_link( $link ) {

	$offset = strpos( $link, '#more-' );
	if ( $offset ) {
		$end = strpos( $link, '"', $offset );
	}
	if ( $end ) {
		$link = substr_replace( $link, '', $offset, $end-$offset );
	}
	return $link;

}

/**
 * Remove theme-layouts meta box
 * 
 * @since 1.0
 */
function mantel_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );
}

/**
 * Load the breadcrumb-trail
 *
 * @since 1.0
 */
function mantel_breadcrumbs() {

	if ( ! is_page_template( 'page-templates/landing.php' ) ) {
	
	?>

		<div class="head-elements">
			<div class="blocks">
				<?php if ( current_theme_supports( 'breadcrumb-trail' ) ) breadcrumb_trail( array( 'before' => __( 'You are here: ', 'mantel' ) ) ); ?>
				<?php get_template_part( 'loop', 'meta' ); ?>
			</div><!-- .blocks -->
		</div><!-- .head-elements -->

	<?php

	}
	
}

/**
 * Filter size of the gravatar on comments.
 * 
 * @since 1.0
 */
function mantel_comments_args( $args ) {

	$args['avatar_size'] = 60;

	return $args;
}

/**
 * Flush rewrite rules
 * 
 * @since 1.0
 */
function mantel_flush_rewrite_rules() {
	global $pagenow;

	if ( 'themes.php' == $pagenow && isset( $_GET['activated'] ) )
		flush_rewrite_rules();

}

/**
 * Default footer settings
 *
 * @since 1.0
 */
function mantel_default_footer_settings( $settings ) {
    
    $settings['footer_insert'] = __( 'Copyright &#169; [the-year] [site-link]', 'mantel' );
    
    return $settings;
}

/**
 * Add no widgets layout.
 *
 * @since 1.0
 */
function mantel_register_theme_layout( $strings ) {

	$strings['1c-full'] = __( 'Full Width', 'mantel' );

	return $strings;

}
?>